@@ -4,6 +4,5 @@ import appEvents from './app_events';
 import { profiler } from './profiler';
 import { contextSrv } from './services/context_srv';
 import TimeSeries, { updateLegendValues } from './time_series2';
-import { assignModelProperties } from './utils/model_utils';
 
-export { profiler, appEvents, colors, assignModelProperties, contextSrv, JsonExplorer, TimeSeries, updateLegendValues };
+export { profiler, appEvents, colors, contextSrv, JsonExplorer, TimeSeries, updateLegendValues };
